@@ -1,13 +1,13 @@
 import random
 import copy
 
-from . import colors
-from . import console
-from . import nbinput
+from ... import colors
+from ... import console
+from ... import nbinput
 
-from . import canvas
-from . import sprite
-from . import shapes
+from ... import canvas
+from ... import sprite
+from ... import shapes
 
 BOTTOM, DOWN, LEFT, TOP, UP, RIGHT = 0, 0, 1, 2, 2, 3
 
